import React, { useEffect, useState } from 'react'
import { useCryptoService } from '../../../services'
import { BVCrypto } from '../../generic'
import { BVRefresh } from '../../generic/BVRefresh/BVRefresh'

import './MainPage.css'

export function MainPage() {
	const [bitcoin, setBitcoin] = useState({})
	const [ethereum, setEthereum] = useState({})
	const [litecoin, setLitecoin] = useState({})
	const { getCryptoInfo } = useCryptoService()

	const fetchAll = () => {
		fetchBitcoin()
		fetchEthereum()
		fetchLitecoin()
	}

	const fetchBitcoin = async () => {
		setBitcoin(await getCryptoInfo('btc'))
	}

	const fetchEthereum = async () => {
		setEthereum(await getCryptoInfo('eth'))
	}

	const fetchLitecoin = async () => {
		setLitecoin(await getCryptoInfo('ltc'))
	}

	useEffect(() => {
		fetchAll()
	}, [])

	const renderCrypto = (crypto, name) => {
		return (
			<BVCrypto
				key={crypto.actualPrice}
				worthBuying={crypto.worthBuying}
				name={name}
				price={crypto.actualPrice}
			/>
		)
	}

	return (
		<div className="MainPage">
			<BVRefresh refreshCallback={fetchAll} />
			{renderCrypto(bitcoin, 'Bitcoin')}
			{renderCrypto(ethereum, 'Ethereum')}
			{renderCrypto(litecoin, 'Litecoin')}
		</div>
	)
}
